@@ -1,15 +1,17 @@
 use std::collections::HashMap;
 use std::io::Error;
 use std::string::FromUtf8Error;
+use std::sync::Arc;
 
 use streamduck_core::core::button::Button;
 use streamduck_core::core::RawButtonPanel;
 use streamduck_core::modules::components::{ComponentDefinition, UIPathValue};
+use streamduck_core::modules::events::SDGlobalEvent;
 use streamduck_core::modules::PluginMetadata;
 use streamduck_core::socket::{SocketError, SocketPacket};
 pub use streamduck_daemon as daemon;
 use streamduck_daemon::daemon_data::assets::{AddImageResult, ListImagesResult, RemoveImageResult};
-use streamduck_daemon::daemon_data::buttons::{AddComponentResult, AddComponentValueResult, ClearButtonResult, GetButtonResult, GetComponentValuesResult, NewButtonFromComponentResult, NewButtonResult, RemoveComponentResult, RemoveComponentValueResult, SetButtonResult, SetComponentValueResult};
+use streamduck_daemon::daemon_data::buttons::{AddComponentResult, AddComponentValueResult, ClearButtonResult, ClipboardStatusResult, CopyButtonResult, GetButtonResult, GetComponentValuesResult, NewButtonFromComponentResult, NewButtonResult, PasteButtonResult, RemoveComponentResult, RemoveComponentValueResult, SetButtonResult, SetComponentValueResult};
 use streamduck_daemon::daemon_data::config::{ExportDeviceConfigResult, GetDeviceConfigResult, ImportDeviceConfigResult, ReloadDeviceConfigResult, ReloadDeviceConfigsResult, SaveDeviceConfigResult, SaveDeviceConfigsResult};
 use streamduck_daemon::daemon_data::devices::{AddDeviceResult, Device, GetDeviceResult, RemoveDeviceResult, SetBrightnessResult};
 use streamduck_daemon::daemon_data::modules::{AddModuleValueResult, GetModuleValuesResult, RemoveModuleValueResult, SetModuleValueResult};
@@ -19,11 +21,32 @@ use streamduck_daemon::daemon_data::panels::{DropStackToRootResult, ForciblyPopS
 #[cfg(target_family = "unix")]
 pub mod unix;
 
+#[cfg(target_family = "windows")]
+pub mod windows;
 
 pub mod util;
 
-/// Trait that defines a client, implementations of clients must be separate due to conditional compiling
-pub trait SDClient {
+/// Trait that combines both types of clients
+pub trait SDSyncClient: SDSyncUpcastRequestClient + SDSyncUpcastEventClient {}
+
+/// Trait that allows to cast from Client to RequestClient
+pub trait SDSyncUpcastRequestClient: SDSyncRequestClient {
+    fn as_request(self: Arc<Self>) -> Arc<dyn SDSyncRequestClient>;
+}
+
+/// Trait that allows to cast from Client to EventClient
+pub trait SDSyncUpcastEventClient: SDSyncEventClient {
+    fn as_event(self: Arc<Self>) -> Arc<dyn SDSyncEventClient>;
+}
+
+/// Trait that defines synchronous event client
+pub trait SDSyncEventClient: Send + Sync {
+    /// Retrieves an event from daemon, depending on implementation might block
+    fn get_event(&self) -> Result<SDGlobalEvent, SDClientError>;
+}
+
+/// Trait that defines synchronous request client
+pub trait SDSyncRequestClient: Send + Sync {
     // Version
     /// Retrieves version of the daemon socket API
     fn version(&self) -> Result<String, SDClientError>;
@@ -102,6 +125,13 @@ pub trait SDClient {
     /// Clears a button from current screen of a device
     fn clear_button(&self, serial_number: &str, key: u8) -> Result<ClearButtonResult, SDClientError>;
 
+    /// Returns status of clipboard on daemon
+    fn clipboard_status(&self) -> Result<ClipboardStatusResult, SDClientError>;
+    /// Copies button into daemon's clipboard
+    fn copy_button(&self, serial_number: &str, key: u8) -> Result<CopyButtonResult, SDClientError>;
+    /// Pastes button from daemon's clipboard
+    fn paste_button(&self, serial_number: &str, key: u8) -> Result<PasteButtonResult, SDClientError>;
+
     /// Creates a new empty button on current screen of a device
     fn new_button(&self, serial_number: &str, key: u8) -> Result<NewButtonResult, SDClientError>;
     /// Creates a button from component on current screen of a device
